@@ -1,5 +1,5 @@
 
--- libquvi-scripts v0.4.1
+-- libquvi-scripts v0.4.3
 -- Copyright (C) 2010  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -32,6 +32,10 @@ function suffix_from_contenttype(ctype)
             ..'incomplete.')
     end
 
+    if ctype:find("audio/mpeg") then
+        return "mp3"
+    end
+
     local _,_,s = ctype:find("/(.-)$")
     s = s or error ("no match: content type")
     s = s:gsub("^x%-","")
